@@ -77,8 +77,8 @@ void gdk_pre_parse_libgtk_only          (void);
 
 #ifndef GDK_DISABLE_DEPRECATED
 void  	  gdk_exit		   	(gint	    	 error_code);
-#endif /* GDK_DISABLE_DEPRECATED */
 gchar*	  gdk_set_locale	   	(void);
+#endif /* GDK_DISABLE_DEPRECATED */
 
 G_CONST_RETURN char *gdk_get_program_class (void);
 void                 gdk_set_program_class (const char *program_class);
@@ -96,15 +96,12 @@ gboolean  gdk_get_use_xshm		(void);
 gchar*	                  gdk_get_display		(void);
 G_CONST_RETURN gchar*	  gdk_get_display_arg_name	(void);
 
-#if !defined (GDK_DISABLE_DEPRECATED) || defined (GTK_COMPILATION)
-/* Used by gtk_input_add_full () */
+#ifndef GDK_DISABLE_DEPRECATED
 gint gdk_input_add_full	  (gint		     source,
 			   GdkInputCondition condition,
 			   GdkInputFunction  function,
 			   gpointer	     data,
-			   GdkDestroyNotify  destroy);
-#endif /* !GDK_DISABLE_DEPRECATED || GTK_COMPILATION */
-#ifndef GDK_DISABLE_DEPRECATED
+			   GDestroyNotify    destroy);
 gint gdk_input_add	  (gint		     source,
 			   GdkInputCondition condition,
 			   GdkInputFunction  function,
@@ -195,26 +192,34 @@ GDKVAR GMutex *gdk_threads_mutex; /* private */
 GDKVAR GCallback gdk_threads_lock;
 GDKVAR GCallback gdk_threads_unlock;
 
-void     gdk_threads_enter                (void);
-void     gdk_threads_leave                (void);
-void     gdk_threads_init                 (void);
-void     gdk_threads_set_lock_functions   (GCallback enter_fn,
-					   GCallback leave_fn);
+void     gdk_threads_enter                    (void);
+void     gdk_threads_leave                    (void);
+void     gdk_threads_init                     (void);
+void     gdk_threads_set_lock_functions       (GCallback enter_fn,
+					       GCallback leave_fn);
 
-guint    gdk_threads_add_idle_full        (gint           priority,
-		                           GSourceFunc    function,
-		                           gpointer       data,
-		                           GDestroyNotify notify);
-guint    gdk_threads_add_idle             (GSourceFunc    function,
-		                           gpointer       data);
-guint    gdk_threads_add_timeout_full     (gint           priority,
-                                           guint          interval,
-                                           GSourceFunc    function,
-                                           gpointer       data,
-                                           GDestroyNotify notify);
-guint    gdk_threads_add_timeout          (guint          interval,
-                                           GSourceFunc    function,
-                                           gpointer       data);
+guint    gdk_threads_add_idle_full            (gint           priority,
+		                               GSourceFunc    function,
+		                               gpointer       data,
+		                               GDestroyNotify notify);
+guint    gdk_threads_add_idle                 (GSourceFunc    function,
+		                               gpointer       data);
+guint    gdk_threads_add_timeout_full         (gint           priority,
+                                               guint          interval,
+                                               GSourceFunc    function,
+                                               gpointer       data,
+                                               GDestroyNotify notify);
+guint    gdk_threads_add_timeout              (guint          interval,
+                                               GSourceFunc    function,
+                                               gpointer       data);
+guint    gdk_threads_add_timeout_seconds_full (gint           priority,
+                                               guint          interval,
+                                               GSourceFunc    function,
+                                               gpointer       data,
+                                               GDestroyNotify notify);
+guint    gdk_threads_add_timeout_seconds      (guint          interval,
+                                               GSourceFunc    function,
+                                               gpointer       data);
 
 #ifdef	G_THREADS_ENABLED
 #  define GDK_THREADS_ENTER()	G_STMT_START {	\
