@@ -363,7 +363,7 @@ popup_position_func (GtkMenu  *menu,
   gint monitor_num;
   GdkRectangle monitor;
   
-  g_return_if_fail (GTK_WIDGET_REALIZED (link_button));
+  g_return_if_fail (gtk_widget_get_realized (widget));
 
   gdk_window_get_origin (widget->window, x, y);
 
@@ -412,7 +412,7 @@ gtk_link_button_do_popup (GtkLinkButton  *link_button,
       time = gtk_get_current_event_time ();
     }
 
-  if (GTK_WIDGET_REALIZED (link_button))
+  if (gtk_widget_get_realized (GTK_WIDGET (link_button)))
     {
       GtkWidget *menu_item;
       
@@ -452,7 +452,7 @@ static gboolean
 gtk_link_button_button_press (GtkWidget      *widget,
 			      GdkEventButton *event)
 {
-  if (!GTK_WIDGET_HAS_FOCUS (widget))
+  if (!gtk_widget_has_focus (widget))
     gtk_widget_grab_focus (widget);
 
   if ((event->button == 3) && (event->type == GDK_BUTTON_PRESS))
@@ -716,6 +716,8 @@ gtk_link_button_get_uri (GtkLinkButton *link_button)
  * Return value: the previously set hook function.
  *
  * Since: 2.10
+ *
+ * Deprecated: 2.24: Use the #GtkButton::clicked signal instead
  */
 GtkLinkButtonUriFunc
 gtk_link_button_set_uri_hook (GtkLinkButtonUriFunc func,
